@@ -68,7 +68,7 @@ class config(object):
     bugtracker_user         = None
     bugtracker_pass         = None
 
-    github_url              = "https://github.com/wine-compholio/wine-staging"
+    github_url              = "https://github.com/wine-staging/wine-staging"
 
 class PatchUpdaterError(RuntimeError):
     """Failed to update patches."""
@@ -219,6 +219,7 @@ def load_patchsets():
 
         # No single patch within this directory, ignore it
         if len(patch.patches) == 0:
+            print "WARNING: No patches found in directory %s" % (directory)
             del patch
             continue
 
@@ -420,7 +421,7 @@ def check_bug_status(all_patches, sync_bugs=False):
 
     once = True
     for bug in bug_list['bugs']:
-        if bug['status'] != "STAGED" or bug['cf_staged_patchset'] != url_map[bug['id']]:
+        if bug['status'] != "STAGED":
             if once:
                 print ""
                 print "WARNING: The following bugs might require attention:"
@@ -430,6 +431,10 @@ def check_bug_status(all_patches, sync_bugs=False):
                                                   bug['resolution'], bug['cf_staged_patchset'])
             if sync_bugs:
                 sync_bug_status(bugtracker, bug, url_map[bug['id']])
+        if bug['status'] == 'STAGED' and \
+           bug['cf_staged_patchset'] != url_map[bug['id']] and \
+           bug['cf_staged_patchset'] != url_map[bug['id']].replace('github.com/wine-staging','github.com/wine-compholio'):
+            print 'Invalid staged patchset: #%d - \"%s\" - %s' %(bug['id'], bug['summary'], bug['cf_staged_patchset'])
 
     once = True
     for bug in staged_bugs['bugs']:
@@ -763,6 +768,7 @@ if __name__ == "__main__":
     parser.add_argument('--skip-checks', action='store_true', help="Skip dependency checks")
     parser.add_argument('--commit', type=_check_commit_hash, help="Use given commit hash instead of HEAD")
     parser.add_argument('--sync-bugs', action='store_true', help="Update bugs in bugtracker (requires admin rights)")
+    parser.add_argument('--skip-bugs', action='store_true', help="Skip bugtracker checks")
     args = parser.parse_args()
 
     tools_directory = os.path.dirname(os.path.realpath(__file__))
@@ -783,7 +789,8 @@ if __name__ == "__main__":
         all_patches = load_patchsets()
 
         # Check bugzilla
-        check_bug_status(all_patches, sync_bugs=args.sync_bugs)
+        if not args.skip_bugs:
+            check_bug_status(all_patches, sync_bugs=args.sync_bugs)
 
         # Update autogenerated files
         generate_ifdefined(all_patches, skip_checks=args.skip_checks)
